@@ -1,5 +1,5 @@
 use anchor_lang::prelude::*;
-use vipers::assert_keys;
+use vipers::assert_keys_eq;
 use vipers::validate::Validate;
 
 use crate::AcceptAdmin;
@@ -16,12 +16,12 @@ use crate::TransferAdmin;
 
 impl<'info> Validate<'info> for NewWrapper<'info> {
     fn validate(&self) -> ProgramResult {
-        assert_keys!(
+        assert_keys_eq!(
             self.token_mint.mint_authority.unwrap(),
             self.mint_wrapper,
             "mint authority"
         );
-        assert_keys!(
+        assert_keys_eq!(
             self.token_mint.freeze_authority.unwrap(),
             self.mint_wrapper,
             "freeze authority"
@@ -40,7 +40,7 @@ impl<'info> Validate<'info> for NewMinter<'info> {
 impl<'info> Validate<'info> for MinterUpdate<'info> {
     fn validate(&self) -> ProgramResult {
         self.auth.validate()?;
-        assert_keys!(
+        assert_keys_eq!(
             self.minter.mint_wrapper,
             self.auth.mint_wrapper,
             "mint_wrapper"
@@ -52,7 +52,7 @@ impl<'info> Validate<'info> for MinterUpdate<'info> {
 impl<'info> Validate<'info> for TransferAdmin<'info> {
     fn validate(&self) -> ProgramResult {
         require!(self.admin.is_signer, Unauthorized);
-        assert_keys!(self.admin, self.mint_wrapper.admin, "admin");
+        assert_keys_eq!(self.admin, self.mint_wrapper.admin, "admin");
         Ok(())
     }
 }
@@ -60,7 +60,7 @@ impl<'info> Validate<'info> for TransferAdmin<'info> {
 impl<'info> Validate<'info> for AcceptAdmin<'info> {
     fn validate(&self) -> ProgramResult {
         require!(self.pending_admin.is_signer, Unauthorized);
-        assert_keys!(
+        assert_keys_eq!(
             self.pending_admin,
             self.mint_wrapper.pending_admin,
             "pending admin"
@@ -79,14 +79,14 @@ impl<'info> Validate<'info> for PerformMint<'info> {
 
         require!(self.minter_authority.is_signer, Unauthorized);
         require!(self.minter.allowance > 0, MinterAllowanceExceeded);
-        assert_keys!(self.minter.mint_wrapper, self.mint_wrapper, "mint wrapper");
-        assert_keys!(
+        assert_keys_eq!(self.minter.mint_wrapper, self.mint_wrapper, "mint wrapper");
+        assert_keys_eq!(
             self.minter_authority,
             self.minter.minter_authority,
             "minter"
         );
-        assert_keys!(self.token_mint, self.mint_wrapper.token_mint, "token mint");
-        assert_keys!(self.destination.mint, self.token_mint, "dest token mint");
+        assert_keys_eq!(self.token_mint, self.mint_wrapper.token_mint, "token mint");
+        assert_keys_eq!(self.destination.mint, self.token_mint, "dest token mint");
         Ok(())
     }
 }
@@ -98,7 +98,7 @@ impl<'info> Validate<'info> for PerformMint<'info> {
 impl<'info> Validate<'info> for OnlyAdmin<'info> {
     fn validate(&self) -> ProgramResult {
         require!(self.admin.is_signer, Unauthorized);
-        assert_keys!(self.admin, self.mint_wrapper.admin, "admin");
+        assert_keys_eq!(self.admin, self.mint_wrapper.admin, "admin");
         Ok(())
     }
 }
